@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1335 USA
  */
 
 #include <config.h>
@@ -31,9 +31,7 @@
 #include "unicode-nameslist.h"
 #include "unicode-categories.h"
 #include "unicode-versions.h"
-#if ENABLE_UNIHAN
-# include "unicode-unihan.h"
-#endif
+#include "unicode-unihan.h"
 
 /* constants for hangul (de)composition, see UAX #15 */
 #define SBase 0xAC00
@@ -63,16 +61,17 @@ static const gchar JAMO_T_TABLE[][4] = {
 const gchar *
 gucharmap_get_unicode_name (gunichar wc)
 {
-  static gchar buf[32];
+  static gchar buf[64];
 
   _gucharmap_intl_ensure_initialized ();
 
   if ((wc >= 0x3400 && wc <= 0x4db5)
-      || (wc >= 0x4e00 && wc <= 0x9fd5)
+      || (wc >= 0x4e00 && wc <= 0x9fef)
       || (wc >= 0x20000 && wc <= 0x2a6d6)
       || (wc >= 0x2a700 && wc <= 0x2b734)
       || (wc >= 0x2b740 && wc <= 0x2b81d)
-      || (wc >= 0x2b820 && wc <= 0x2cea1))
+      || (wc >= 0x2b820 && wc <= 0x2cea1)
+      || (wc >= 0x2ceb0 && wc <= 0x2ebe0))
     {
       g_snprintf (buf, sizeof (buf), "CJK UNIFIED IDEOGRAPH-%04X", wc);
       return buf;
@@ -82,7 +81,7 @@ gucharmap_get_unicode_name (gunichar wc)
       g_snprintf (buf, sizeof (buf), "CJK COMPATIBILITY IDEOGRAPH-%04X", wc);
       return buf;
   }
-  else if (wc >= 0x17000 && wc <= 0x187ec) {
+  else if (wc >= 0x17000 && wc <= 0x187f7) {
       g_snprintf (buf, sizeof (buf), "TANGUT IDEOGRAPH-%05X", wc);
       return buf;
   }
@@ -240,8 +239,6 @@ gucharmap_unicode_version_to_string (GucharmapUnicodeVersion version)
   return unicode_version_strings + unicode_version_string_offsets[version - 1];
 }
 
-#if ENABLE_UNIHAN
-
 gint
 gucharmap_get_unihan_count (void)
 {
@@ -286,58 +283,6 @@ _get_unihan (gunichar uc)
   return NULL;
 }
 
-#else /* #if ENABLE_UNIHAN */
-
-gint
-gucharmap_get_unihan_count ()
-{
-  return 0;
-}
-
-const gchar * 
-gucharmap_get_unicode_kDefinition (gunichar uc)
-{
-  return "This feature was not compiled in.";
-}
-
-const gchar * 
-gucharmap_get_unicode_kCantonese (gunichar uc)
-{
-  return "This feature was not compiled in.";
-}
-
-const gchar * 
-gucharmap_get_unicode_kMandarin (gunichar uc)
-{
-  return "This feature was not compiled in.";
-}
-
-const gchar * 
-gucharmap_get_unicode_kTang (gunichar uc)
-{
-  return "This feature was not compiled in.";
-}
-
-const gchar * 
-gucharmap_get_unicode_kKorean (gunichar uc)
-{
-  return "This feature was not compiled in.";
-}
-
-const gchar * 
-gucharmap_get_unicode_kJapaneseKun (gunichar uc)
-{
-  return "This feature was not compiled in.";
-}
-
-const gchar * 
-gucharmap_get_unicode_kJapaneseOn (gunichar uc)
-{
-  return "This feature was not compiled in.";
-}
-
-#endif /* #else (#if ENABLE_UNIHAN) */
-
 /* does a binary search; also caches most recent, since it will often be
  * called in succession on the same character */
 static const NamesList *
@@ -654,8 +599,24 @@ gucharmap_unichar_isgraph (gunichar uc)
 {
   GUnicodeType t = gucharmap_unichar_type (uc);
 
+  /* From http://www.unicode.org/versions/Unicode9.0.0/ch09.pdf, p16
+   * "Unlike most other format control characters, however, they should be
+   *  rendered with a visible glyph, even in circumstances where no suitable
+   *  digit or sequence of digits follows them in logical order."
+   * There the standard talks about the ar signs spanning numbers, but
+   * I think this should apply to all Prepended_Concatenation_Mark format
+   * characters.
+   * Instead of parsing the corresponding data file, just hardcode the
+   * (few!) existing characters here.
+   */
+  if (t == G_UNICODE_FORMAT)
+    return (uc >= 0x0600 && uc <= 0x0605) || 
+	   uc == 0x06DD ||
+           uc == 0x070F ||
+           uc == 0x08E2 ||
+           uc == 0x110BD;
+
   return (t != G_UNICODE_CONTROL
-          && t != G_UNICODE_FORMAT
           && t != G_UNICODE_UNASSIGNED
           && t != G_UNICODE_PRIVATE_USE
           && t != G_UNICODE_SURROGATE
