@@ -414,7 +414,7 @@ help_about (GSimpleAction *action,
       "Noah Levitt <nlevitt@columbia.edu>", 
       "Daniel Elstner <daniel.elstner@gmx.net>", 
       "Padraig O'Briain <Padraig.Obriain@sun.com>",
-      "Christian Persch <" "chpe" "\100" "gnome" "." "org" ">",
+      "Christian Persch <" "chpe" "\100" "src.gnome" "." "org" ">",
       "DaeHyun Sung <sungdh86@gmail.com>",
       NULL 
     };
@@ -454,10 +454,10 @@ help_about (GSimpleAction *action,
   gtk_show_about_dialog (GTK_WINDOW (guw),
 			 "program-name", _("GNOME Character Map"),
 			 "version", VERSION,
-			 "comments", _("Based on the Unicode Character Database 10.0.0"),
+			 "comments", _("Based on the Unicode Character Database 12.0.0"),
 			 "copyright", "Copyright © 2004 Noah Levitt\n"
-				      "Copyright © 1991–2017 Unicode, Inc.\n"
-				      "Copyright © 2007–2017 Christian Persch\n"
+				      "Copyright © 1991–2019 Unicode, Inc.\n"
+				      "Copyright © 2007–2019 Christian Persch\n"
                                       "Copyright © 2016 DaeHyun Sung",
 			 "documenters", documenters,
 			 "license", license_trans,
